# Luxsci.Api.ContentLibraryApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

| Method | HTTP request | Description |
|--------|--------------|-------------|
| [**CreateContentLibraryDirectory**](ContentLibraryApi.md#createcontentlibrarydirectory) | **PUT** /user/{username}/content_library/{directory} |  |
| [**DeleteContentLibraryDirectory**](ContentLibraryApi.md#deletecontentlibrarydirectory) | **DELETE** /user/{username}/content_library/{directory} |  |
| [**DeleteContentLibraryFile**](ContentLibraryApi.md#deletecontentlibraryfile) | **DELETE** /user/{username}/content_library/{file_path} |  |
| [**GetContentLibraryDirectory**](ContentLibraryApi.md#getcontentlibrarydirectory) | **GET** /user/{username}/content_library/{directory} |  |
| [**GetContentLibraryFile**](ContentLibraryApi.md#getcontentlibraryfile) | **GET** /user/{username}/content_library/{file_path} |  |
| [**UploadContentLibraryFile**](ContentLibraryApi.md#uploadcontentlibraryfile) | **PUT** /user/{username}/content_library/{file_path} |  |

<a name="createcontentlibrarydirectory"></a>
# **CreateContentLibraryDirectory**
> Authentication201Response CreateContentLibraryDirectory (string username, string directory, string? cookie = null)



Create a new Content Library directory.  {{ACL: User Email: Content Library}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class CreateContentLibraryDirectoryExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new ContentLibraryApi(config);
            var username = "username_example";  // string | 
            var directory = files/media/;  // string | Starting with the / following /content_library, this is the directory in {username} to create. This directory must not exist and, if it is a subdirectory, the parent directories must all exist.
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                Authentication201Response result = apiInstance.CreateContentLibraryDirectory(username, directory);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling ContentLibraryApi.CreateContentLibraryDirectory: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the CreateContentLibraryDirectoryWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<Authentication201Response> response = apiInstance.CreateContentLibraryDirectoryWithHttpInfo(username, directory);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling ContentLibraryApi.CreateContentLibraryDirectoryWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **directory** | **string** | Starting with the / following /content_library, this is the directory in {username} to create. This directory must not exist and, if it is a subdirectory, the parent directories must all exist. |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**Authentication201Response**](Authentication201Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** |  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="deletecontentlibrarydirectory"></a>
# **DeleteContentLibraryDirectory**
> Authentication201Response DeleteContentLibraryDirectory (string username, string directory, string? cookie = null)



Delete an empty Content Library directory.  {{ACL: User Email: Content Library}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class DeleteContentLibraryDirectoryExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new ContentLibraryApi(config);
            var username = "username_example";  // string | 
            var directory = files/media/;  // string | Starting with the / following /content_library, this is the directory in {username} to create. This directory must not exist and, if it is a subdirectory, the parent directories must all exist.
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                Authentication201Response result = apiInstance.DeleteContentLibraryDirectory(username, directory);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling ContentLibraryApi.DeleteContentLibraryDirectory: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the DeleteContentLibraryDirectoryWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<Authentication201Response> response = apiInstance.DeleteContentLibraryDirectoryWithHttpInfo(username, directory);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling ContentLibraryApi.DeleteContentLibraryDirectoryWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **directory** | **string** | Starting with the / following /content_library, this is the directory in {username} to create. This directory must not exist and, if it is a subdirectory, the parent directories must all exist. |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**Authentication201Response**](Authentication201Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** |  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="deletecontentlibraryfile"></a>
# **DeleteContentLibraryFile**
> Authentication201Response DeleteContentLibraryFile (string username, string filePath, string? cookie = null)



Delete a file.  {{ACL: User Email: Content Library}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class DeleteContentLibraryFileExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new ContentLibraryApi(config);
            var username = "username_example";  // string | 
            var filePath = files/media/image.jpg;  // string | Required. Starting with the / following /content_library, this is the path of the file in {username} to delete.  The path must not end in a training slash. Be sure to not use double slashes.  Example: \"/files/media/image.jpg\".
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                Authentication201Response result = apiInstance.DeleteContentLibraryFile(username, filePath);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling ContentLibraryApi.DeleteContentLibraryFile: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the DeleteContentLibraryFileWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<Authentication201Response> response = apiInstance.DeleteContentLibraryFileWithHttpInfo(username, filePath);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling ContentLibraryApi.DeleteContentLibraryFileWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **filePath** | **string** | Required. Starting with the / following /content_library, this is the path of the file in {username} to delete.  The path must not end in a training slash. Be sure to not use double slashes.  Example: \&quot;/files/media/image.jpg\&quot;. |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**Authentication201Response**](Authentication201Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** |  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getcontentlibrarydirectory"></a>
# **GetContentLibraryDirectory**
> GetContentLibraryDirectory200Response GetContentLibraryDirectory (string username, string? directory = null, string? cookie = null)



Retrieve details about the specific Content Library directory. {{ACL: User Email: Content Library}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetContentLibraryDirectoryExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new ContentLibraryApi(config);
            var username = "username_example";  // string | 
            var directory = files/media/;  // string? | Starting with the / following /content_library, this is the directory in {username} to examine.  The path must end in a training slash. Be sure to not use double slashes.  Note, for example, that for directory \"/files/media/\" you would insert \"files/media/\" in this variable. If this value is omitted, the contents of the top-level directory will be returned. (optional) 
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetContentLibraryDirectory200Response result = apiInstance.GetContentLibraryDirectory(username, directory);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling ContentLibraryApi.GetContentLibraryDirectory: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetContentLibraryDirectoryWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetContentLibraryDirectory200Response> response = apiInstance.GetContentLibraryDirectoryWithHttpInfo(username, directory);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling ContentLibraryApi.GetContentLibraryDirectoryWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **directory** | **string?** | Starting with the / following /content_library, this is the directory in {username} to examine.  The path must end in a training slash. Be sure to not use double slashes.  Note, for example, that for directory \&quot;/files/media/\&quot; you would insert \&quot;files/media/\&quot; in this variable. If this value is omitted, the contents of the top-level directory will be returned. | [optional]  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetContentLibraryDirectory200Response**](GetContentLibraryDirectory200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | The response contains two main parts.  \&quot;meta\&quot; reflects details about the directory requested and \&quot;items\&quot; is a list of details about the files and directories in this directory. |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getcontentlibraryfile"></a>
# **GetContentLibraryFile**
> GetContentLibraryFile200Response GetContentLibraryFile (string username, string filePath, string? cookie = null)



Retrieve details about the specific Content Library file.  {{ACL: User Email: Content Library}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class GetContentLibraryFileExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new ContentLibraryApi(config);
            var username = "username_example";  // string | 
            var filePath = files/media/image.jpg;  // string | Required. Starting with the / following /content_library, this is the path of the file in {username}.  The path must not end in a training slash. Be sure to not use double slashes.  Example: \"/files/media/image.jpg\".
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 

            try
            {
                GetContentLibraryFile200Response result = apiInstance.GetContentLibraryFile(username, filePath);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling ContentLibraryApi.GetContentLibraryFile: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the GetContentLibraryFileWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetContentLibraryFile200Response> response = apiInstance.GetContentLibraryFileWithHttpInfo(username, filePath);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling ContentLibraryApi.GetContentLibraryFileWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **filePath** | **string** | Required. Starting with the / following /content_library, this is the path of the file in {username}.  The path must not end in a training slash. Be sure to not use double slashes.  Example: \&quot;/files/media/image.jpg\&quot;. |  |
| **cookie** | **string?** |  | [optional]  |

### Return type

[**GetContentLibraryFile200Response**](GetContentLibraryFile200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** |  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="uploadcontentlibraryfile"></a>
# **UploadContentLibraryFile**
> GetContentLibraryFile200Response UploadContentLibraryFile (string username, string filePath, string? cookie = null, UploadContentLibraryFileRequest? uploadContentLibraryFileRequest = null)



Upload a new file to the Content Library.  {{ACL: User Email: Content Library}}

### Example
```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Luxsci.Api;
using Luxsci.Client;
using Luxsci.Model;

namespace Example
{
    public class UploadContentLibraryFileExample
    {
        public static void Main()
        {
            Configuration config = new Configuration();
            config.BasePath = "https://rest.luxsci.com/perl/api/v2";
            var apiInstance = new ContentLibraryApi(config);
            var username = "username_example";  // string | 
            var filePath = files/media/image.jpg;  // string | Required. Starting with the / following /content_library, this is the path in {username} to place the file.  The path must not end in a training slash. Be sure to not use double slashes. Example: \"files/media/image.jpg\".
            var cookie = signature=66843253-1617892797-e5a3f01353817e6fb1fc9bdd0cb2466fa0c4cab44206b52a929ec850510a3b9c:cb814df2717ce7240594092eba854fbb67e9a2504c38b6f525687b4d0c079857;  // string? |  (optional) 
            var uploadContentLibraryFileRequest = new UploadContentLibraryFileRequest?(); // UploadContentLibraryFileRequest? |  (optional) 

            try
            {
                GetContentLibraryFile200Response result = apiInstance.UploadContentLibraryFile(username, filePath, cookie, uploadContentLibraryFileRequest);
                Debug.WriteLine(result);
            }
            catch (ApiException  e)
            {
                Debug.Print("Exception when calling ContentLibraryApi.UploadContentLibraryFile: " + e.Message);
                Debug.Print("Status Code: " + e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

#### Using the UploadContentLibraryFileWithHttpInfo variant
This returns an ApiResponse object which contains the response data, status code and headers.

```csharp
try
{
    ApiResponse<GetContentLibraryFile200Response> response = apiInstance.UploadContentLibraryFileWithHttpInfo(username, filePath, cookie, uploadContentLibraryFileRequest);
    Debug.Write("Status Code: " + response.StatusCode);
    Debug.Write("Response Headers: " + response.Headers);
    Debug.Write("Response Body: " + response.Data);
}
catch (ApiException e)
{
    Debug.Print("Exception when calling ContentLibraryApi.UploadContentLibraryFileWithHttpInfo: " + e.Message);
    Debug.Print("Status Code: " + e.ErrorCode);
    Debug.Print(e.StackTrace);
}
```

### Parameters

| Name | Type | Description | Notes |
|------|------|-------------|-------|
| **username** | **string** |  |  |
| **filePath** | **string** | Required. Starting with the / following /content_library, this is the path in {username} to place the file.  The path must not end in a training slash. Be sure to not use double slashes. Example: \&quot;files/media/image.jpg\&quot;. |  |
| **cookie** | **string?** |  | [optional]  |
| **uploadContentLibraryFileRequest** | [**UploadContentLibraryFileRequest?**](UploadContentLibraryFileRequest?.md) |  | [optional]  |

### Return type

[**GetContentLibraryFile200Response**](GetContentLibraryFile200Response.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** |  |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

